@@ -1,6 +1,6 @@
 """Commands and control for the Onkyo eISCP interface.
 """
 
-__author__ = 'Will Nowak <wan@ccs.neu.edu>'
+__author__ = 'Michael Elsdoerfer <michael@elsdoerfer.com>'
 
 from core import eISCP
