@@ -181,13 +181,30 @@ def command_to_iscp(command, arguments=None, zone=None):
         raise ValueError('"%s" is not a valid command in zone "%s"'
                 % (command, zone))
 
-    # TODO: For now, only support one; though some rare commands would
-    # need multiple.
+    # Resolve the argument to the command. This is a bit more involved,
+    # because some commands support ranges (volume) or patterns
+    # (setting tuning frequency). In some cases, we might imagine
+    # providing the user an API with multiple arguments (TODO: not
+    # currently supported).
     argument = arguments[0]
-    value = commands.VALUE_MAPPINGS[group][prefix].get(argument, argument)
-    if not value in commands.COMMANDS[group][prefix]['values']:
-        raise ValueError('"%s" is not a valid argument for command '
-                         '"%s" in zone "%s"' % (argument, command, zone))
+
+    # 1. Consider if there is a alias, e.g. level-up for UP.
+    try:
+        value = commands.VALUE_MAPPINGS[group][prefix][argument]
+    except KeyError:
+        # 2. See if we can match a range or pattern
+        for possible_arg in commands.VALUE_MAPPINGS[group][prefix]:
+            if argument.isdigit():
+                if isinstance(possible_arg, xrange):
+                    if int(argument) in possible_arg:
+                        # We need to send the format "FF", hex() gives us 0xff
+                        value = hex(int(argument))[2:].upper()
+                    break
+
+            # TODO: patterns not yet supported
+        else:
+            raise ValueError('"%s" is not a valid argument for command '
+                             '"%s" in zone "%s"' % (argument, command, zone))
 
     return '%s%s' % (prefix, value)
 
@@ -201,6 +218,14 @@ def iscp_to_command(iscp_message):
             if args in zone_cmds[command]['values']:
                 return zone_cmds[command]['name'], \
                        zone_cmds[command]['values'][args]['name']
+            else:
+                match = re.match('[+-]?[0-9a-f]$', args, re.IGNORECASE)
+                if match:
+                    return zone_cmds[command]['name'], \
+                             int(args, 16)
+                else:
+                    return zone_cmds[command]['name'], args
+
     else:
         raise ValueError(
             'Cannot convert ISCP message to command: %s' % iscp_message)
@@ -218,12 +243,12 @@ def filter_for_message(getter_func, msg):
         if candidate and candidate[:3] == msg[:3]:
             return candidate
         # The protocol docs claim that a response  should arrive
-        # within *50ms or the communication as failed*. In my tests,
+        # within *50ms or the communication has failed*. In my tests,
         # however, the interval needed to be at least 200ms before
-        # I managed to see any response, aand only after 300ms
+        # I managed to see any response, and only after 300ms
         # reproducably, so use a generous timeout.
-        if time.time() - start > 0.7:
-            raise ValueError('Not received a response')
+        if time.time() - start > 1.5:
+            raise ValueError('Timeout waiting for response.')
 
 
 class eISCP(object):
@@ -350,8 +375,8 @@ class eISCP(object):
         a response, there is no fool-proof way to differentiate those
         from unsolicited status updates, though we'll do our best to
         try. Generally, this won't be an issue, though in theory the
-        response this functino returns to you sending ``SLI05`` may be
-        a ``SLI06`` update from another controller.
+        response this function returns to you sending ``SLI05`` may be
+        an ``SLI06`` update from another controller.
 
         It'd be preferable to design your app in a way where you are
         processing all incoming messages the same way, regardless of
